# PROCESS DOROTHEA DATA - STAGE 2.

source("../../select.r")
source("../../pca.r")
source("../../plot.r")

# Find pvalues for tests of association of features with class. 

pval.hyper.trim <- hyper.pval(train.n0[ix.trim],train.n1[ix.trim])

# Produce plot of p-values.

postscript("dorothea2a.ps",horizontal=TRUE)

minp <- 0.5/length(ix.trim)

plot (pmax(minp,sort(pval.hyper.trim)), pch=20, log="y", ylab="",
      xlab="Binary hypergeometric p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

dev.off()

# Select a set of features using these pvalues.

sel <- order(pval.hyper.trim)[1:683] # p-value <= 0.001
ix.sel <- ix.trim[sel]

write.ix(ix.sel,"sel")
write.data(ix.sel,"sel")

# Find the first 40 principle components from the trimmed set of features.
# Temporarily remove train.x, valid.x, and test.x to save space.
#
# WARNING:  Space is tight on a Pentium system for these commands.  It may
# be necessary to quit R at some point and then restart in order to get it
# to make optimal use of memory.  (This may vary with the version of R used.)

valid.trim <- valid.x[,ix.trim]
rm(valid.x)
train.trim <- train.x[,ix.trim]
rm(train.x)
test.trim <- test.x[,ix.trim]
rm(test.x)

all.trim <- rbind(train.trim,valid.trim,test.trim)
rm(train.trim,valid.trim,test.trim)

pca.trim <- 
  pca.vectors (all.trim, 40, center=FALSE, scale=FALSE)  # TAKES ABOUT 5 MINUTES
                                                     # REQUIRES ABOUT 2.3 GBYTES
rm(all.trim)

read.sparse.binary(nvars=100000)  # Read train.x, valid.x, and test.x again
valid.trim <- valid.x[,ix.trim]
rm(valid.x)
train.trim <- train.x[,ix.trim]
rm(train.x)
test.trim <- test.x[,ix.trim]
rm(test.x)

write.pca (pca.trim, "pc", train.trim, valid.trim, test.trim)

rm(train.trim,valid.trim,test.trim)
read.sparse.binary(nvars=100000)  # Read train.x, valid.x, and test.x again
